both_ends: Target both algebraic ends.

View source: R/classes.R

both_endsR Documentation

Target both algebraic ends.

Description

Target both algebraic ends.

Usage

both_ends(k_low, k_high)

Arguments

k_low

Number of values to select from the smallest algebraic end.

k_high

Number of values to select from the largest algebraic end.

Value

An eigencore_target descriptor selecting both algebraic ends (ARPACK BE).


eigencore documentation built on July 26, 2026, 1:06 a.m.