View source: R/operator_algebra.R
| center | R Documentation |
Center an operator by rows or columns.
center(
A,
rows = FALSE,
columns = TRUE,
row_means = NULL,
col_means = NULL,
name = NULL
)
A |
Operator-like object. |
rows |
Whether to subtract row means. |
columns |
Whether to subtract column means. |
row_means |
Optional row means. Required for matrix-free row centering when they cannot be derived without densifying. |
col_means |
Optional column means. Required for matrix-free column centering when they cannot be derived without densifying. |
name |
Optional label for the centered operator. |
An eigencore_operator representing the centered linear map.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.