Methods for the stats::residuals() generic: return the per-pair (or
per-triplet) residual norms stored in an eigencore result or certificate.
Methods for the stats::residuals() generic: return the per-pair (or
per-triplet) residual norms stored in an eigencore result or certificate.