View source: R/preconditioners.R
| shifted_diagonal_preconditioner | R Documentation |
Shifted diagonal preconditioner.
shifted_diagonal_preconditioner(A, shift = 0)
A |
Diagonal matrix or numeric vector containing the diagonal entries. |
shift |
Non-negative diagonal shift added before inversion. |
A typed native-backed preconditioner function mapping residual blocks to preconditioned blocks.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.