Skip to contents

Target both algebraic ends.

Usage

both_ends(k_low, k_high)

Arguments

k_low

Number of values to select from the smallest algebraic end.

k_high

Number of values to select from the largest algebraic end.

Value

An eigencore_target descriptor selecting both algebraic ends (ARPACK BE).