View source: R/generalized_schur.R
| generalized_schur | R Documentation |
generalized_schur() is eigencore's dense QZ surface for general matrix
pencils A x = lambda B x. It computes the generalized Schur pair S, T
and, when requested, left/right Schur vectors Q, Z such that
A = Q S Z* and B = Q T Z* for complex inputs, with transpose replacing
conjugate-transpose for real inputs. Sparse and operator inputs are not
silently densified.
generalized_schur(A, B, sort = NULL, vectors = TRUE, ...)
A |
Base dense square matrix. |
B |
Base dense square matrix with the same dimension as |
sort |
Optional LAPACK sorting class. Use |
vectors |
Whether to compute Schur vectors |
... |
Reserved for future options. |
A classed generalized Schur result with fields S, T, Q, Z,
alpha, beta, values, classification, sdim, method, plan, and
certificate.
A <- matrix(c(0, -1, 1, 0), 2, 2)
B <- diag(2)
qz <- generalized_schur(A, B)
values(qz)
pencil <- generalized_schur(diag(c(2, 3, 0)), diag(c(1, 0, 0)),
sort = "infinite")
pencil$classification
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.