View source: R/certification.R
| left_vectors | R Documentation |
For SVD results this returns the left singular vectors U. For
nonsymmetric and dense general-pencil eigen results this returns left
eigenvectors when the solver computed them (for example, the dense
general-pencil eig_full() path, which computes left generalized
eigenvectors satisfying w^H A = lambda w^H B).
left_vectors(x, ...)
x |
An eigencore SVD or eigen result object. |
... |
Reserved for future methods. |
A matrix of left singular vectors or left eigenvectors, or NULL
when the result does not contain a left-vector field.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.